==> ukui-biometric-auth_1.2.1.orig.tar.gz: ukui-biometric-auth/bioauth-bin/i18n_ts/ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>BioDevices</name>
    <message>
        <source>FingerPrint</source>
        <translation>FingerPrint</translation>
    </message>
    <message>
        <source>FingerVein</source>
        <translation>FingerVein</translation>
    </message>
    <message>
        <source>Iris</source>
        <translation>Ирис</translation>
    </message>
    <message>
        <source>Face</source>
        <translation>Лицо</translation>
    </message>
    <message>
        <source>VoicePrint</source>
        <translation>Voiceprint</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Try it again</source>
        <translation>Попробуйте снова</translation>
    </message>
    <message>
        <source>Use other Devices</source>
        <translation>Использовать другие устройства</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Choose the option</source>
        <translation>Выберите вариант</translation>
    </message>
    <message>
        <source>Invaild response &quot;</source>
        <translation>Invaild response \ &quot;</translation>
    </message>
    <message>
        <source>AUTHENTICATION CANCELED</source>
        <translation>АВТОРИЗАЦИЯ ОТМЕНА</translation>
    </message>
    <message>
        <source>=== BIOMETRIC DEVICES ===</source>
        <translation>=== БИОМЕТРИЧЕСКИЕ УСТРОЙСТВА ===</translation>
    </message>
    <message>
        <source>Choose the device</source>
        <translation>Выберите устройство</translation>
    </message>
    <message>
        <source>Sevice Name</source>
        <translation>Имя ячейки</translation>
    </message>
    <message>
        <source>DISPLAY env</source>
        <translation>DISPLAY env</translation>
    </message>
    <message>
        <source>User</source>
        <translation>пользователь</translation>
    </message>
    <message>
        <source>Display debug information</source>
        <translation>Отображать отладочную информацию</translation>
    </message>
    <message>
        <source>Device short name</source>
        <translation>Краткое название устройства</translation>
    </message>
    <message>
        <source>BIOMETRIC AUTHENTICATION</source>
        <translation>БИОМЕТРИЧЕСКАЯ АУТЕНТИФИКАЦИЯ</translation>
    </message>
    <message>
        <source>Press Q or Esc to cancel</source>
        <translation>Нажмите Q или Esc, чтобы отменить</translation>
    </message>
    <message>
        <source>AUTHENTICATION SUCCESS</source>
        <translation>УСПЕХ АУТЕНТИФИКАЦИИ</translation>
    </message>
    <message>
        <source>AUTHENTICATION FAILED</source>
        <translation>АВТОРИЗАЦИЯ НЕИСПРАВНО</translation>
    </message>
    <message>
        <source>BIOMETRIC AUTHENTICATION END</source>
        <translation>КОНТРОЛЬ БИОМЕТРИЧЕСКОЙ АВТОРИЗАЦИИ</translation>
    </message>
</context>
</TS>

==> ukui-biometric-auth_1.2.2.orig.tar.gz: ukui-biometric-auth/bioauth-bin/i18n_ts/ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>BioDevices</name>
    <message>
        <source>FingerPrint</source>
        <translation type="vanished">FingerPrint</translation>
    </message>
    <message>
        <source>FingerVein</source>
        <translation type="vanished">FingerVein</translation>
    </message>
    <message>
        <source>Iris</source>
        <translation type="vanished">Ирис</translation>
    </message>
    <message>
        <source>Face</source>
        <translation type="vanished">Лицо</translation>
    </message>
    <message>
        <source>VoicePrint</source>
        <translation type="vanished">Voiceprint</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Try it again</source>
        <translation>Попробуйте снова</translation>
    </message>
    <message>
        <source>Use other Devices</source>
        <translation>Использовать другие устройства</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Choose the option</source>
        <translation>Выберите вариант</translation>
    </message>
    <message>
        <source>Invaild response &quot;</source>
        <translation>Invaild response \ &quot;</translation>
    </message>
    <message>
        <source>AUTHENTICATION CANCELED</source>
        <translation>АВТОРИЗАЦИЯ ОТМЕНА</translation>
    </message>
    <message>
        <source>=== BIOMETRIC DEVICES ===</source>
        <translation>=== БИОМЕТРИЧЕСКИЕ УСТРОЙСТВА ===</translation>
    </message>
    <message>
        <source>Choose the device</source>
        <translation>Выберите устройство</translation>
    </message>
    <message>
        <source>Sevice Name</source>
        <translation>Имя ячейки</translation>
    </message>
    <message>
        <source>DISPLAY env</source>
        <translation>DISPLAY env</translation>
    </message>
    <message>
        <source>User</source>
        <translation>пользователь</translation>
    </message>
    <message>
        <source>Display debug information</source>
        <translation>Отображать отладочную информацию</translation>
    </message>
    <message>
        <source>Device short name</source>
        <translation>Краткое название устройства</translation>
    </message>
    <message>
        <source>BIOMETRIC AUTHENTICATION</source>
        <translation>БИОМЕТРИЧЕСКАЯ АУТЕНТИФИКАЦИЯ</translation>
    </message>
    <message>
        <source>Press Q or Esc to cancel</source>
        <translation>Нажмите Q или Esc, чтобы отменить</translation>
    </message>
    <message>
        <source>AUTHENTICATION SUCCESS</source>
        <translation>УСПЕХ АУТЕНТИФИКАЦИИ</translation>
    </message>
    <message>
        <source>AUTHENTICATION FAILED</source>
        <translation>АВТОРИЗАЦИЯ НЕИСПРАВНО</translation>
    </message>
    <message>
        <source>BIOMETRIC AUTHENTICATION END</source>
        <translation>КОНТРОЛЬ БИОМЕТРИЧЕСКОЙ АВТОРИЗАЦИИ</translation>
    </message>
    <message>
        <source>authentication will be canceld</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
